<?php
/*******************************************

class.pager.php

info:       Smarty page splitter
date:       2006.01.21
author:     Igor Shatokhin (igshat@gawab.com)

copyright:   2005 by SeoStart
            www.seostart.com
            info@seostart.com

********************************************/
class Pager
{
    var $page;
    var $per_page;
    var $items_count;
    var $pages_count = 0;
    var $first_on_page = 0;
    var $last_on_page = 0;
    var $prev = 0;
    var $next = 0;
    var $array;                 // link to array (if pager works with array)

    //
    // constructor
    // $count_or_array - pass items count or array
    //
    function Pager($count_or_array, $per_page=10, $page=1)
    {
        if( is_array($count_or_array) ) {
            $this->items_count = count($count_or_array);
            $this->array = &$count_or_array;
        } else {
            $this->items_count = intval($count_or_array);
        }
        $this->per_page = $per_page > 0 ? intval($per_page) : 1;
        $this->set_page($page);
    }

    //
    // set current page
    //
    function set_page($page)
    {
        $pages_count = ceil($this->items_count / $this->per_page);
        if( $page < 1 ) $page = 1;
        if( $page > $pages_count ) $page = $pages_count;
        $this->page = intval($page);
    }

    //
    // get SQL "LIMIT" construction
    //
    function sql_limit()
    {
        $this->calculate();
        return "LIMIT " . $this->first_on_page . "," . $this->per_page;
    }

    //
    // return current page from $this->array
    //
    function get_part()
    {
        if( !is_array($this->array) ) return false;
        $this->calculate();
        $part = array();
        $cur = 0;
        foreach($this->array as $key=>$val) {
            if( $cur>=$this->first_on_page and $cur<=$this->last_on_page )
                $part[$key] = $val;
            $cur++;
        }
        return $part;
    }

    //
    // get array for display page selector
    //
    function get_pages($first_last=true, $prev_next=true, $max_display_pages=10, $one_page_display=false)
    {
        $this->calculate();
        if( !$one_page_display and $this->pages_count<=1 ) return array();
        $pages = array();
        if($this->prev) {
            if($first_last) $pages['first'] = array('page'=>1, 'value'=>'<<');
            if($prev_next) $pages['prev'] = array('page'=>$this->page-1, 'value'=>'<');
        }
        if($max_display_pages and $max_display_pages < $this->pages_count) {
            $start = $this->page - ( floor($max_display_pages/2) );
            if($start<1) $start = 1;
            $end = $start + $max_display_pages - 1;
            if($end>$this->pages_count) {
                $end = $this->pages_count;
                $start = $end - $max_display_pages + 1;
            }
        } else {
            $start = 1;
            $end = $this->pages_count;
        }
        for($i=$start; $i<=$end; $i++) {
            if($i==$this->page) $pages[$i]['is_current'] = 1;
            $pages[$i]['page'] = $i;
            $pages[$i]['value'] = $i;
        }
        if($this->next) {
            if($prev_next) $pages['next'] = array('page'=>$this->page+1, 'value'=>'>');
            if($first_last) $pages['last'] = array('page'=>$this->pages_count, 'value'=>'>>');
        }
        return $pages;
    }

    //
    // service function
    //
    function calculate()
    {
        $this->pages_count = ceil($this->items_count / $this->per_page);
        $this->prev = $this->page>1 ? 1:0;
        $this->next = $this->page<$this->pages_count ? 1:0;
        if($this->items_count) {
            $this->first_on_page = $this->per_page * $this->page - $this->per_page;
            $this->last_on_page = $this->next ? $this->first_on_page+$this->per_page-1 : $this->items_count-1;
        } else {
            $this->first_on_page = 0;
            $this->last_on_page = 0;
        }
    }

} // end class Pager
?>