<?php
/********************************************

func.files.php

info:       files management functions
date:       2006.01.24
author:     Igor Shatokhin (igshat@gawab.com)

 by SeoStart
www.seostart.com
info@seostart.com

*********************************************/

//
// load file
//
function file_load($fname)
{
    $fp=fopen($fname, 'rb');
    if( $fp===false )   return false;

    $content = '';
    while( !feof($fp) )
        $content .= fread($fp, 2048);

    fclose($fp);
    return $content;
}

//
// save file
//
function file_save($fname, $content)
{
    $fp=fopen($fname, 'wb');
    if( $fp===false )   return false;

    $bytes = fwrite($fp, $content);

    fclose($fp);
    return $bytes;
}

//
// append file
//
function file_append($fname, $content)
{
    $fp = fopen($fname, 'ab');
    if( $fp===false )   return false;

    $bytes = fwrite($fp, $content);

    fclose($fp);
    return $bytes;
}

//
// save object to file
//
function object_save($fname, $obj)
{
    $str = serialize( $obj );
    if( $str===false )  return false;

    if( file_save($fname, $str)===false )   return false;
    return true;
}

//
// load object from file
//
function object_load($fname)
{
    $str = file_load($fname);
    if( $str===false )  return false;

    return unserialize( $str );
}

//
// save array to file
//
function array_save($fname, $arr)
{
    $fp=fopen($fname, 'wb');
    if( $fp===false )   return false;

    foreach($arr as $val)
        if( fwrite($fp, $val."\r\n")===false ) return false;

    fclose($fp);
    return true;
}

//
// load array from the strings of file
//
function array_load($fname)
{
    $arr = file($fname);
    if( $arr===false )  return false;

    foreach($arr as $key=>$val) $arr[$key] = rtrim($val);
    return $arr;
}

//
// delete file or recursive directory delete
// return FALSE if cannot delete at least one item
//
function unlink_r($item)
{
    if( is_dir($item) ) {
        $ok = true;
        $dir = dir($item);
        while( false!==($entry=$dir->read()) ) {
            if( $entry=='.' or $entry=='..' ) continue;
            if( !unlink_r($dir->path.'/'.$entry) ) $ok = false;
        }
        $dir->close();
        return $ok ? @rmdir($item) : false;
    }
    return @unlink($item);
}

//
// copy file or directory to another directory (must be exist)
// return FALSE if cannot copy at least one item
//
function copy_r($item, $dest_dir, $mode=0777)
{
    $dest_dir = realpath($dest_dir).'/';
    if( !is_dir($dest_dir) ) return false;
    $item = realpath($item);
    $name = preg_replace("<^.*?([^/\\\]+)[/\\\]?$>i", "$1", $item);

    if( is_dir($item) ) {
        $new_dir = $dest_dir.$name.'/';
        if( !is_dir($new_dir) and !@mkdir($new_dir, $mode) ) return false;
        $ok = true;
        $dir = dir($item);
        while( false!==($entry=$dir->read()) ) {
            if( $entry=='.' or $entry=='..' ) continue;
            if( !copy_r($dir->path.'/'.$entry, $new_dir, $mode) ) $ok = false;
        }
        $dir->close();
        return $ok;
    }
    return @copy($item, $dest_dir.basename($item) );
}

//
// move file or directory to another directory (must be exist)
// return FALSE if cannot move at least one item
//
function move_r($item, $dest_dir, $mode=0777)
{
    if( !copy_r($item, $dest_dir, $mode) ) return false;
    if( !unlink_r($item) ) return false;
    return true;
}

//
// check for errors and move uploaded file
// $inp_name    :input name from HTML-form
// $dest_dir    :destination directory
// $rename      :specify for rename file
// $max_size    :max file size, 0 if no limit (works only if smallest than upload_max_filesize in php.ini)
// $allowed_types :array with allowed MIME-types of file (no limit if empty)
// return TRUE or FALSE with setup global variable $file_upload_error
//
function file_upload($inp_name, $dest_dir, $rename='', $max_size=0, $allowed_types=array() )
{
    $upl = &$_FILES[$inp_name];
    $err = &$GLOBALS['file_upload_error'];
    if( empty($upl) ) return false;
    if( $upl['error']==UPLOAD_ERR_INI_SIZE
    or  $upl['error']==UPLOAD_ERR_FORM_SIZE
    or  ($max_size and $upl['size'] > $max_size) ) {
        $err = "File is too large";
        return false;
    }
    if( $upl['error']==UPLOAD_ERR_PARTIAL
    or  $upl['error']==UPLOAD_ERR_NO_FILE ) {
        $err = "File uploading error";
        return false;
    }
    if( $upl['error']!=UPLOAD_ERR_OK ) {
        $err = "Unknown error";
        return false;
    }
    if( !empty($allowed_types) and !in_array($upl['type'],$allowed_types) ) {
        $err = "Invalid file type";
        return false;
    }
    $dest_dir = realpath($dest_dir).'/';
    $rename = $rename ? $rename : $upl['name'];
    if( !@move_uploaded_file($upl['tmp_name'],$dest_dir.$rename) ) {
        $err = "Cannot move uploaded file";
        return false;
    }
    return true;
}



?>
